@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -113,6 +110,7 @@ bool IOFWAsyncCommand::initAll(IOFireWireNub *device, FWAddress devAddress,
 			fSpeed = fMembers->fMaxSpeed;
 		}
 		fFailOnReset = failOnReset;
+		fMembers->fAckCode = 0;
 	}
 		
     return success;
@@ -163,6 +161,7 @@ bool IOFWAsyncCommand::initAll(IOFireWireController *control,
 			fSpeed = fMembers->fMaxSpeed;
 		}
 		fFailOnReset = true;
+		fMembers->fAckCode = 0;
 	}
 	
     return success;
@@ -263,6 +262,8 @@ IOReturn IOFWAsyncCommand::reinit(FWAddress devAddress, IOMemoryDescriptor *host
 		fSpeed = fMembers->fMaxSpeed;
 	}
     fFailOnReset = failOnReset;
+	fMembers->fAckCode = 0;
+	
     return fStatus = kIOReturnSuccess;
 }
 
@@ -297,6 +298,8 @@ IOReturn IOFWAsyncCommand::reinit(UInt32 generation, FWAddress devAddress, IOMem
 	{
 		fSpeed = fMembers->fMaxSpeed;
 	}
+	fMembers->fAckCode = 0;
+
     return fStatus = kIOReturnSuccess;
 }
 
@@ -400,7 +403,10 @@ IOReturn IOFWAsyncCommand::complete(IOReturn status)
 void IOFWAsyncCommand::gotAck(int ackCode)
 {
     int rcode;
-    switch (ackCode) 
+    
+	setAckCode( ackCode );
+
+	switch( ackCode ) 
 	{
 		case kFWAckPending:
 			// This shouldn't happen.
@@ -430,6 +436,28 @@ void IOFWAsyncCommand::gotAck(int ackCode)
     gotPacket(rcode, NULL, 0);
 }
 
+// setAckCode
+//
+//
+
+void IOFWAsyncCommand::setAckCode( int ack )
+{
+	fMembers->fAckCode = ack;
+}
+
+// getAckCode
+//
+//
+
+int IOFWAsyncCommand::getAckCode( void )
+{
+	return fMembers->fAckCode;
+}
+
+// setMaxSpeed
+//
+//
+
 void IOFWAsyncCommand::setMaxSpeed( int speed ) 
 { 
 	fMembers->fMaxSpeed = speed;
