@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -56,6 +53,7 @@ protected:
 	
 	bool 		fTerminated;
 	IOFWSpeed	fMaxSpeed;
+	UInt32		fUnitCount;
 	
 	/*! 
 		@struct ExpansionData
@@ -79,6 +77,9 @@ protected:
 
 	void setMaxSpeed( IOFWSpeed speed );
 	
+	void setUnitCount( UInt32 count );
+	UInt32 getUnitCount( void );
+	
 private:
     OSMetaClassDeclareReservedUnused(IOFireWireDeviceAux, 0);
     OSMetaClassDeclareReservedUnused(IOFireWireDeviceAux, 1);
@@ -205,6 +206,14 @@ protected:
 public:
 	inline void setMaxSpeed( IOFWSpeed speed )
 		{ ((IOFireWireDeviceAux*)fAuxiliary)->setMaxSpeed( speed ); }		
+
+protected:
+	inline void setUnitCount( UInt32 count )
+		{ ((IOFireWireDeviceAux*)fAuxiliary)->setUnitCount( count ); }		
+
+public:
+	inline UInt32 getUnitCount( void )
+		{ return ((IOFireWireDeviceAux*)fAuxiliary)->getUnitCount(); }		
 	
 private:
     OSMetaClassDeclareReservedUnused(IOFireWireDevice, 0);
